@@ -43,6 +43,8 @@ class experiment(item.item):
 		A special item that controls the flow of the experiment.
 	"""
 
+	description = u'The main experiment item'
+
 	def __init__(self, name=u'experiment', string=None, pool_folder=None,
 		experiment_path=None, fullscreen=False, auto_response=False,
 		logfile=u'defaultlog.csv', subject_nr=0, workspace=None, resources={},
@@ -121,44 +123,7 @@ class experiment(item.item):
 		self.resources = resources
 		self.paused = False
 		self.output_channel = None
-
-		# Set default variables
-		self.var.start = u'experiment'
-		self.var.title = self.default_title
-		self.var.bidi = u'no'
-		self.var.round_decimals = 2
-		self.var.form_clicks = u'no'
-		self.var.disable_garbage_collection = u'yes'
-		# In version 2.9.X and before, the sketchpad used 0,0 for the screen
-		# center, whereas scripting items used 0,0 for the top-left. By setting
-		# uniform_coordinates to 'yes', 0,0 is used for the center in all cases.
-		self.var.uniform_coordinates = u'no'
-
-		# Sound parameters
-		self.var.sound_freq = 48000
-		self.var.sound_sample_size = -16 # Negative values mean signed
-		self.var.sound_channels = 2
-		self.var.sound_buf_size = 1024
-
-		# Default backend
-		self.var.canvas_backend = u'xpyriment'
-
-		# Display parameters
-		self.var.width = 1024
-		self.var.height = 768
-		self.var.background = u'black'
-		self.var.foreground = u'white'
-		if fullscreen:
-			self.var.fullscreen = u'yes'
-		else:
-			self.var.fullscreen = u'no'
-
-		# Font parameters
-		self.var.font_size = 18
-		self.var.font_family = u'mono'
-		self.var.font_italic = u'no'
-		self.var.font_bold = u'no'
-		self.var.font_underline = u'no'
+		self.reset()
 
 		# Logfile parameters
 		self._log = None
@@ -175,6 +140,9 @@ class experiment(item.item):
 		item.item.__init__(self, name, self, string)
 		# Default subject info
 		self.set_subject(subject_nr)
+		# Fullscreen needs to be set after the experiment has been parsed from
+		# script, otherwise it will be overridden by the script.
+		self.var.fullscreen = u'yes' if fullscreen else u'no'
 		# Restore experiment path, which is either the full path (including
 		# filename), only the folder, or None.
 		if experiment_path is not None:
@@ -219,6 +187,40 @@ class experiment(item.item):
 			DeprecationWarning)
 		return self.pool[path]
 
+	def reset(self):
+
+		"""See item."""
+
+		# Set default variables
+		self.var.start = u'experiment'
+		self.var.title = self.default_title
+		self.var.bidi = u'no'
+		self.var.round_decimals = 2
+		self.var.form_clicks = u'no'
+		self.var.disable_garbage_collection = u'yes'
+		# In version 2.9.X and before, the sketchpad used 0,0 for the screen
+		# center, whereas scripting items used 0,0 for the top-left. By setting
+		# uniform_coordinates to 'yes', 0,0 is used for the center in all cases.
+		self.var.uniform_coordinates = u'no'
+		# Sound parameters
+		self.var.sound_freq = 48000
+		self.var.sound_sample_size = -16 # Negative values mean signed
+		self.var.sound_channels = 2
+		self.var.sound_buf_size = 1024
+		# Default backend
+		self.var.canvas_backend = u'xpyriment'
+		# Display parameters
+		self.var.width = 1024
+		self.var.height = 768
+		self.var.background = u'black'
+		self.var.foreground = u'white'
+		# Font parameters
+		self.var.font_size = 18
+		self.var.font_family = u'mono'
+		self.var.font_italic = u'no'
+		self.var.font_bold = u'no'
+		self.var.font_underline = u'no'
+
 	def file_in_pool(self, path):
 
 		"""Deprecated."""
@@ -309,13 +311,14 @@ class experiment(item.item):
 			string:	The definition string.
 		"""
 
-		self.variables = {}
+		self.var.clear(preserve=[u'experiment_path', u'experiment_file'])
+		self.reset()
 		self.comments = []
 		debug.msg(u"building experiment")
 		if string is None:
 			return
 		self.front_matter, string = self._syntax.parse_front_matter(string)
-		if self.experiment.front_matter[u'API'] < 2:
+		if self.experiment.front_matter[u'API'].version[0] < 2:
 			# Old experiment scripts were saved in ASCII, and require decoding
 			# of U+XXXX unicode characters.
 			string = self.syntax.from_ascii(string)
@@ -326,10 +329,9 @@ class experiment(item.item):
 			try:
 				l = self.syntax.split(line)
 			except ValueError as e:
-				raise osexception(
-					u"Failed to parse script. Maybe it contains illegal characters or unclosed quotes?", \
-					exception=e)
-			if len(l) > 0:
+				raise osexception(u'Failed to parse script. Maybe it contains '
+					u'illegal characters or unclosed quotes?', exception=e)
+			if l:
 				self.parse_variable(line)
 				# Parse definitions
 				if l[0] == u"define":
@@ -485,6 +487,7 @@ class experiment(item.item):
 		if not gc.isenabled():
 			print('experiment.end(): enabling garbage collection')
 			gc.enable()
+		self.transmit_workspace(__finished__=True)
 
 	def to_string(self):
 
@@ -618,10 +621,15 @@ class experiment(item.item):
 			type:	str
 		"""
 
-		# If the path is not a path at all, but a string containing
-		# the script, return it. Also, convert the path back to Unicode before
-		# returning.
-		if not os.path.exists(src):
+		# If the path is not a path at all, but a string containing the script,
+		# return it. Also, convert the path back to Unicode before returning.
+		try:
+			# Checking whether a path exists can appartently trigger a
+			# ValueError when src is too long. Therefore, we use this awkward
+			# construction.
+			if not os.path.exists(src):
+				raise ValueError('Path doesn\'t exist)')
+		except ValueError: 
 			debug.msg(u'opening from unicode string')
 			self.experiment_path = None
 			return safe_decode(src, errors=u'replace')
